@@ -15,8 +15,10 @@
 #
 
 import mock
+import webob
 
 from neutron.db import servicetype_db as st_db
+from neutron.quota import resource_registry
 from neutron.tests import base as n_base
 from neutron.tests.unit.db import test_db_base_plugin_v2
 from neutron.tests.unit.extensions import base as ext_base
@@ -206,10 +208,27 @@ class NeutronDbPluginV2TestCase(
         expected_res.reverse()
         self.assertEqual(expected_res, [n['id'] for n in item_res])
 
+    def _delete(self, collection, id,
+                expected_code=webob.exc.HTTPNoContent.code,
+                neutron_context=None, subresource=None, sub_id=None):
+        req = self.new_delete_request(collection, id, subresource=subresource,
+                                      sub_id=sub_id)
+        if neutron_context:
+            # create a specific auth context for this request
+            req.environ['neutron.context'] = neutron_context
+        res = req.get_response(self._api_for_resource(collection))
+        self.assertEqual(res.status_int, expected_code)
+
 
 class ExtensionTestCase(ext_base.ExtensionTestCase):
     pass
 
 
 class QuotaExtensionTestCase(test_quotasv2.QuotaExtensionTestCase):
-    pass
+
+    def setUp(self):
+        super(QuotaExtensionTestCase, self).setUp()
+        resource_registry.register_resource_by_name('pool')
+        resource_registry.register_resource_by_name('loadbalancer')
+        resource_registry.register_resource_by_name('listener')
+        resource_registry.register_resource_by_name('healthmonitor')
