@@ -13,6 +13,10 @@ enable_plugin barbican https://git.openstack.org/openstack/barbican
 # Sort out our gate args
 . $(dirname "$0")/decode_args.sh
 
+if egrep --quiet '(vmx|svm)' /proc/cpuinfo; then
+    export DEVSTACK_GATE_LIBVIRT_TYPE=kvm
+fi
+
 
 function _setup_octavia {
     export DEVSTACK_LOCAL_CONFIG+="
@@ -50,6 +54,21 @@ EOF
 
 case "$testtype" in
 
+    "dsvm-functional")
+        PROJECT_NAME=neutron-lbaas
+        NEUTRON_LBAAS_PATH=$GATE_DEST/$PROJECT_NAME
+        DEVSTACK_PATH=$GATE_DEST/devstack
+        IS_GATE=True
+        USE_CONSTRAINT_ENV=False
+        export LOG_COLOR=False
+        source "$NEUTRON_LBAAS_PATH"/tools/configure_for_lbaas_func_testing.sh
+
+        # Make the workspace owned by the stack user
+        sudo chown -R "$STACK_USER":"$STACK_USER" "$BASE"
+
+        configure_host_for_lbaas_func_testing
+        ;;
+
     "tempest")
         # These are not needed with either v1 or v2
         ENABLED_SERVICES+="-c-api,-c-bak,-c-sch,-c-vol,-cinder,"
@@ -66,7 +85,9 @@ case "$testtype" in
             ENABLED_SERVICES+="-ceilometer-collector,"
         fi
 
-        if [ "$testenv" != "apiv1" ]; then
+        if [ "$testenv" == "apiv1" ]; then
+            ENABLED_SERVICES+="q-lbaas,"
+        else
             # Override enabled services, so we can turn on lbaasv2.
             # While we're at it, disable cinder and swift, since we don't need them.
             ENABLED_SERVICES+="q-lbaasv2,-q-lbaas,"
@@ -83,6 +104,7 @@ case "$testtype" in
         fi
 
         export ENABLED_SERVICES
+        "$GATE_DEST"/devstack-gate/devstack-vm-gate.sh
         ;;
 
     *)
@@ -90,6 +112,3 @@ case "$testtype" in
         exit 1
         ;;
 esac
-
-
-"$GATE_DEST"/devstack-gate/devstack-vm-gate.sh
